pub struct AssertSpec {
pub target: String,
pub condition: Expr,
}Fields
target: Stringcondition: ExprTrait Implementations
Sourceimpl Clone for AssertSpec
impl Clone for AssertSpec
Sourcefn clone(&self) -> AssertSpec
fn clone(&self) -> AssertSpec
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssertSpec
impl Debug for AssertSpec
Sourceimpl<'de> Deserialize<'de> for AssertSpec
impl<'de> Deserialize<'de> for AssertSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AssertSpec
impl JsonSchema for AssertSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AssertSpec
impl RefUnwindSafe for AssertSpec
impl Send for AssertSpec
impl Sync for AssertSpec
impl Unpin for AssertSpec
impl UnwindSafe for AssertSpec