pub struct BucketSpec {
pub name: String,
pub operations: HashSet<BucketOperation>,
}Fields
name: Stringoperations: HashSet<BucketOperation>Trait Implementations
Sourceimpl Clone for BucketSpec
impl Clone for BucketSpec
Sourcefn clone(&self) -> BucketSpec
fn clone(&self) -> BucketSpec
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BucketSpec
impl Debug for BucketSpec
Sourceimpl Default for BucketSpec
impl Default for BucketSpec
Sourcefn default() -> BucketSpec
fn default() -> BucketSpec
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BucketSpec
impl<'de> Deserialize<'de> for BucketSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for BucketSpec
impl Display for BucketSpec
Sourceimpl JsonSchema for BucketSpec
impl JsonSchema for BucketSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BucketSpec
impl RefUnwindSafe for BucketSpec
impl Send for BucketSpec
impl Sync for BucketSpec
impl Unpin for BucketSpec
impl UnwindSafe for BucketSpec