pub struct StepSpec {
pub name: String,
pub bucket: Vec<BucketSpec>,
pub watch: Vec<WatchSpec>,
pub apply: Vec<ApplySpec>,
pub delete: Vec<ApplySpec>,
pub script: Vec<ScriptSpec>,
pub sleep: u16,
pub wait: Vec<WaitSpec>,
pub assert: Vec<AssertSpec>,
}Fields
name: Stringbucket: Vec<BucketSpec>watch: Vec<WatchSpec>apply: Vec<ApplySpec>delete: Vec<ApplySpec>script: Vec<ScriptSpec>sleep: u16wait: Vec<WaitSpec>assert: Vec<AssertSpec>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for StepSpec
impl<'de> Deserialize<'de> for StepSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StepSpec
impl JsonSchema for StepSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StepSpec
impl RefUnwindSafe for StepSpec
impl Send for StepSpec
impl Sync for StepSpec
impl Unpin for StepSpec
impl UnwindSafe for StepSpec